=== modified file 'bzrlib/intset.py'
--- bzrlib/intset.py	2005-09-19 06:05:19 +0000
+++ bzrlib/intset.py	2005-12-19 17:48:25 +0000
@@ -208,3 +208,22 @@
         if not self._val & m:
             raise KeyError(to_remove)
         self._val ^= m
+
+    def set_remove(self, to_remove):
+        """Remove all values that exist in to_remove.
+
+        >>> a = IntSet(range(10))
+        >>> b = IntSet([2,3,4,7,12])
+        >>> a.set_remove(b)
+        >>> list(a)
+        [0, 1, 5, 6, 8, 9]
+        >>> a.set_remove([1,2,5])
+        >>> list(a)
+        [0, 6, 8, 9]
+        """
+        if not isinstance(to_remove, IntSet):
+            self.set_remove(IntSet(to_remove))
+            return
+        intersect = self._val & to_remove._val
+        self._val ^= intersect
+

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2005-12-18 15:12:39 +0000
+++ bzrlib/tests/__init__.py	2005-12-19 17:48:25 +0000
@@ -31,6 +31,7 @@
 import bzrlib.branch
 import bzrlib.commands
 from bzrlib.errors import BzrError
+import bzrlib.intset
 import bzrlib.inventory
 import bzrlib.merge3
 import bzrlib.osutils
@@ -47,6 +48,7 @@
                       bzrlib.branch,
                       bzrlib.commands,
                       bzrlib.errors,
+                      bzrlib.intset,
                       bzrlib.inventory,
                       bzrlib.merge3,
                       bzrlib.osutils,

